<?php

/**
* Polytraits team, 2013
* PHP client to access the polytraits database: 
* a. search Polytraits for taxa matching a given query
* b. retrieve the traits information for one or more taxon IDs
**/

// base URL
$traitsapi_url = "http://polytraits.lifewatchgreece.eu";


// ###### a. search Polytraits for taxa matching a given query

// required parameters
$method   = "taxon"; 
$query    = urlencode("Myzostoma");  //any taxon name

// optional parameters: 
// this one's part of the URL
$format   = "json";  // can be either "json" or "xml", though at the moment only json is implemented. Default: "json"

// these are part of the query string
$exact = 0;	// can be either 0 or 1. 0 implements a wildcard search, e.g. "Syllis%", 1 searches for the exact name. Default:1
$verbose = 1; // can be either 0 or 1. 0 returns only the taxon ID and the taxon name, 1 returns additional info. Default:0
$assoc = 0;   // can be either 0 or 1. 0 returns a numeric array, 1 an associative with the taxonID as key(s). Default:0

$querystring = "exact=$exact&verbose=$verbose&assoc=$assoc";

  
// assemble the URL for the query

$request_url = $traitsapi_url."/".$method."/".$query."/".$format."/?". $querystring;


$response = get_headers($request_url);

// print_r($response);

if($response[0]== "HTTP/1.1 200 OK")
{
  $taxonInfo = file_get_contents($request_url);
  $taxonInfo = json_decode($taxonInfo, true);
  
  echo "<pre>";
  print_r($taxonInfo);  // note that this is still utf8-encoded
  echo "</pre>";
}

else
{

  echo "Ooops. There seems to be an error. The message returned by the server is <b>". $response[0] ."</b>" ;	
}



// ###### b. retrieve the traits information available for this taxa


// Let's get the traits for the first two taxa that were returned by the query above:
$txid1 = $taxonInfo[0]["taxonID"];
$txid2 = $taxonInfo[1]["taxonID"];



// required parameter
$method   = "traits"; 
$query    = $txid1.",".$txid2;  //one or more taxon IDs

// optional parameters: 
// this one's part of the URL
$format   = "json";  // can be either "json" or "xml", though at the moment only json is implemented. Default: "json"

// these are part of the query string
$verbose = 1; // can be either 0 or 1. 0 returns only trait, modality and value, 1 returns additional info. Default:1
$assoc = 1;   // can be either 0 or 1. 0 returns a numeric array, 1 an associative with the taxonID as key(s). Default:1

$querystring = "&verbose=$verbose&assoc=$assoc";

  
// assemble the URL for the query

$request_url = $traitsapi_url."/".$method."/".$query."/".$format."/?". $querystring;

$response = get_headers($request_url);

// print_r($response);

if($response[0]== "HTTP/1.1 200 OK")
{
  $traitsInfo = file_get_contents($request_url);
  $traitsInfo = json_decode($traitsInfo, true);
  
  echo "<pre>";
  print_r($traitsInfo);  // note that this is utf8-encoded
  echo "</pre>";
}

else
{

  echo "Ooops. There seems to be an error. The message returned by the server is <b>". $response[0] ."</b>" ;	
}





?>


