#!/usr/bin/perl 



# Polytraits team, 2013
# Perl client to access the polytraits database: 
# a. search Polytraits for taxa matching a given query
# b. retrieve the traits information for one or more taxon IDs

use strict;
use LWP::UserAgent;
use HTTP::Request::Common;
use URI::Escape;
use JSON;
  

my $POLYTRAITS_API_URL = "http://polytraits.lifewatchgreece.eu";

###### a. search Polytraits for taxa matching a given query

# required parameters
my $method   = "taxon"; 
my $query    = uri_escape("Myzostoma");  #any taxon name, URL encoded

# optional parameters: 

# this one's part of the URL
my $format   = "json";  # can be either "json" or "xml", though at the moment only json is implemented. Default: "json"

# these are part of the query string
my $exact = 0;	# can be either 0 or 1. 0 implements a wildcard search, e.g. "Syllis%", 1 searches for the exact name. Default:1
my $verbose = 1; # can be either 0 or 1. 0 returns only the taxon ID and the taxon name, 1 returns additional info. Default:0
my $assoc = 0;   # can be either 0 or 1. 0 returns a numeric array, 1 an associative with the taxonID as key(s). Default:0

my $querystring = "exact=$exact&verbose=$verbose&assoc=$assoc";

  
# assemble the URL for the query
my $request_url = $POLYTRAITS_API_URL."/".$method."/".$query."/".$format."/?". $querystring;

print "-- Contacting: ".$request_url."\n";
my $query_agent = LWP::UserAgent->new(agent => 'perl get');
my $query_response = $query_agent->request(GET $request_url);

my @taxon_info_list = ();

if ($query_response->is_success) {
    
    @taxon_info_list = decode_json ( $query_response->content );
    print uri_unescape($query_response->content)."\n"; #URL decoded
}
else {
    print "Error:\n";
    print $query_response->error_as_HTML;
    exit (1);
}



###### b. retrieve the traits information available for this taxa

##Let's get the traits for the first two taxa that were returned by the query above:
my $txid1 = $taxon_info_list[0][0]{"taxonID"};
my $txid2 = $taxon_info_list[0][1]{"taxonID"};


# #required parameter
$method   = "traits"; 
$query    = $txid1.",".$txid2;  #one or more taxon IDs


## optional parameters: 
# this one's part of the URL
$format   = "json";  # can be either "json" or "xml", though at the moment only json is implemented. Default: "json"


# these are part of the query string
$verbose = 1; # can be either 0 or 1. 0 returns only trait, modality and value, 1 returns additional info. Default:1
$assoc = 1;   # can be either 0 or 1. 0 returns a numeric array, 1 an associative with the taxonID as key(s). Default:1


$querystring = "&verbose=$verbose&assoc=$assoc";

#// assemble the URL for the query
$request_url = $POLYTRAITS_API_URL."/".$method."/".$query."/".$format."/?". $querystring;

print "\n\n\n";
print "-- Contacting: ".$request_url."\n";
$query_agent = LWP::UserAgent->new(agent => 'perl get');
$query_response = $query_agent->request(GET $request_url);


if ($query_response->is_success) {    
    print uri_unescape($query_response->content)."\n"; #URL decoded
}
else {
    print "Error:\n";
    print $query_response->error_as_HTML;
    exit (1);
}

print "-- Done\n";